# PhoneType


## Enum

* `WORK` (value: `'Work'`)

* `MOBILE` (value: `'Mobile'`)

* `HOME` (value: `'Home'`)

* `OTHER` (value: `'Other'`)

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


